@@ -12,12 +12,10 @@ use DynaLoader ();
 
 %EXPORT_TAGS = (
    options => [qw(OPT_NONE OPT_INDEXES OPT_INCLUDES 
-		  OPT_SYMLINKS OPT_EXECCGI OPT_UNSET OPT_INCNOEXEC
+		  OPT_SYM_LINKS OPT_EXECCGI OPT_UNSET OPT_INCNOEXEC
 		  OPT_SYM_OWNER OPT_MULTI OPT_ALL)],
    response_codes => [qw(
 			 DOCUMENT_FOLLOWS
-			 PARTIAL_CONTENT 
-			 MULTIPLE_CHOICES
 			 MOVED
 			 REDIRECT
 			 USE_LOCAL_COPY
@@ -25,18 +23,28 @@ use DynaLoader ();
 			 AUTH_REQUIRED
 			 FORBIDDEN
 			 NOT_FOUND
-			 METHOD_NOT_ALLOWED 
-			 NOT_ACCEPTABLE 
-			 LENGTH_REQUIRED
-			 PRECONDITION_FAILED
+			 HTTP_METHOD_NOT_ALLOWED 
+			 HTTP_NOT_ACCEPTABLE 
+			 HTTP_LENGTH_REQUIRED
+			 HTTP_PRECONDITION_FAILED
 			 SERVER_ERROR 
 			 NOT_IMPLEMENTED
 			 BAD_GATEWAY 
 			 HTTP_SERVICE_UNAVAILABLE
-			 VARIANT_ALSO_VARIES)],
+			 HTTP_VARIANT_ALSO_VARIES)],
     common => [qw(OK DECLINED NOT_FOUND FORBIDDEN AUTH_REQUIRED SERVER_ERROR)],
 );
 
+@EXPORT_OK = qw(
+   MOVED
+   HTTP_METHOD_NOT_ALLOWED 
+   HTTP_NOT_ACCEPTABLE 
+   HTTP_LENGTH_REQUIRED
+   HTTP_PRECONDITION_FAILED
+   HTTP_SERVICE_UNAVAILABLE
+   HTTP_VARIANT_ALSO_VARIES
+);
+   
 @EXPORT = qw(
    AUTH_REQUIRED
    BAD_GATEWAY
@@ -71,11 +79,14 @@ use DynaLoader ();
    REDIRECT
    RESPONSE_CODES
    SERVER_ERROR
-   SERVICE_UNAVAILABLE
    SERVER_VERSION
    USE_LOCAL_COPY
 );
- 
+
+#hmm
+sub MOVED () {301}
+sub AUTH_REQUIRED () {401}
+
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
     # XS function.
