@@ -5,8 +5,8 @@ use Apache::Constants qw(:common &OPT_EXECCGI);
 use FileHandle ();
 
 use vars qw($VERSION $Debug);
-#$Id: Registry.pm,v 1.21 1996/12/19 04:14:51 dougm Exp $
-$VERSION = (qw$Revision: 1.21 $)[1];
+#$Id: Registry.pm,v 1.22 1997/01/23 00:07:50 dougm Exp $
+$VERSION = (qw$Revision: 1.22 $)[1];
 
 $Debug ||= 0;
 # 1 => log recompile in errorlog
@@ -15,10 +15,11 @@ $Debug ||= 0;
 
 sub handler {
     my($r) = @_;
+    Apache->request($r);
     my $filename = $r->filename;
 
     if (-r $filename && -s _) {
-	if (!($r->allow_options & OPT_EXECCGI) && (!$r->is_perlaliased)) {
+	if (!($r->allow_options & OPT_EXECCGI)) {
 	    $r->log_reason("Options ExecCGI is off in this directory", 
 			   $filename);
 	    return FORBIDDEN;
@@ -38,8 +39,9 @@ sub handler {
 	# turn into a package name
 	$r->log_error("Apache::Registry::handler checking out $script_name")
 	    if $Debug & 4;
-	my $script_name = 
-	    substr($r->uri, 0, length($r->uri)-length($r->path_info));
+	my $script_name = $r->path_info ?
+	    substr($r->uri, 0, length($r->uri)-length($r->path_info)) :
+		$r->uri;
 
 	# Escape everything into valid perl identifiers
 	$script_name =~ s/([^A-Za-z0-9\/])/sprintf("_%2x",unpack("C",$1))/eg;
@@ -69,6 +71,7 @@ sub handler {
 	    undef $fh;
 	    # compile this subroutine into the uniq package name
             $r->log_error("Apache::Registry::handler eval-ing") if $Debug & 4;
+ 	    undef &{"$package\:\:handler"}; #avoid warnings 
             my $eval = qq{package $package; sub handler { $sub; }};
             {
                 # hide our variables within this block
@@ -113,11 +116,9 @@ Apache::Registry - Run (mostly) unaltered CGI scripts through mod_perl
  PerlAlias /perl/ /perl/apache/scripts/ #optional
  PerlModule Apache::Registry 
  
- AddHandler perl-script .fpl
- 
- #in access.conf
- <Directory /perl/apache/scripts>
- PerlHandler Apache::Regsistry::handler
+ <Location /perl>
+ SetHandler perl-script
+ PerlHandler Apache::Registry
  ...
  </Directory>
 
